MethodChannelAppleKeychain class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required String key, String? suite}) → Future<String?>
override
toString() → String
A string representation of this object.
inherited
uuid() → Future<String?>
override
write({required String key, required String value, String? suite}) → Future<String?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited